@@ -16,6 +16,7 @@ import hashlib
 import json
 from datetime import datetime as dt
 from itertools import chain
+import copy
 from pywapor.general.logger import log
 from pywapor.collect import accounts
 from pywapor.enhancers.apply_enhancers import apply_enhancer
@@ -258,7 +259,7 @@ def find_VIIRSL1_urls(year_doy_time, product, workdir,
             fp = download_url(url, fp)
 
         # Open the json and find the exact url of the required scene.
-        all_scenes = [x["name"] for x in json.load(open(fp))]
+        all_scenes = [x["name"] for x in json.load(open(fp))["content"]]
         req_scenes = fnmatch.filter(all_scenes, f"{product}.A{year}{doy}.{t}.*.*.nc")
 
         # Check if a corrct url is found.
@@ -475,20 +476,16 @@ def download(folder, latlim, lonlim, timelim, product_name, req_vars,
     if not os.path.exists(folder):
         os.makedirs(folder)
 
-    appending = False
     fn = os.path.join(folder, f"{product_name}.nc")
+    req_vars_orig = copy.deepcopy(req_vars)
     if os.path.isfile(fn):
-        os.rename(fn, fn.replace(".nc", "_to_be_appended.nc"))
-        existing_ds = open_ds(fn.replace(".nc", "_to_be_appended.nc"))
-        if np.all([x in existing_ds.data_vars for x in req_vars]):
+        existing_ds = open_ds(fn)
+        req_vars_new = list(set(req_vars).difference(set(existing_ds.data_vars)))
+        if len(req_vars_new) > 0:
+            req_vars = req_vars_new
             existing_ds = existing_ds.close()
-            os.rename(fn.replace(".nc", "_to_be_appended.nc"), fn)
-            existing_ds = open_ds(fn)
-            return existing_ds[req_vars]
         else:
-            appending = True
-            fn = os.path.join(folder, f"{product_name}_appendix.nc")
-            req_vars = [x for x in req_vars if x not in existing_ds.data_vars]
+            return existing_ds[req_vars_orig]
 
     if isinstance(variables, type(None)):
         variables = default_vars(product_name, req_vars)
@@ -509,7 +506,7 @@ def download(folder, latlim, lonlim, timelim, product_name, req_vars,
     urls = find_VIIRSL1_urls(year_doy_time, "VNP03IMG", folder)
 
     # Create authentication header.
-    token, _ = accounts.get('VIIRSL1')
+    _, token = accounts.get('VIIRSL1')
     headers = {'Authorization': 'Bearer ' + token}
 
     # Try to download the geolocation data.
@@ -544,18 +541,9 @@ def download(folder, latlim, lonlim, timelim, product_name, req_vars,
             ds, label = apply_enhancer(ds, var, func)
             log.info(label)
 
-    ds_new = save_ds(ds, fn, encoding = "initiate", label = "Merging files.")
+    ds = save_ds(ds, fn, encoding = "initiate", label = "Merging files.")
 
-    if appending:
-        ds = xr.merge([ds_new, existing_ds])
-        lbl = f"Appending new variables (`{'`, `'.join(req_vars)}`) to existing file."
-        ds = save_ds(ds, os.path.join(folder, f"{product_name}.nc"), encoding = "initiate", label = lbl)
-        remove_ds(ds_new)
-        remove_ds(existing_ds)
-    else:
-        ds = ds_new
-
-    return ds
+    return ds[req_vars_orig]
 
 if __name__ == "__main__":
 
